@@ -1,29 +1,12 @@
-# --8<--8<--8<--8<--
-#
-# Copyright (C) 2014 Smithsonian Astrophysical Observatory
-#
-# This file is part of IPC::PrettyPipe
-#
-# IPC::PrettyPipe is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or (at
-# your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# -->8-->8-->8-->8--
-
 package IPC::PrettyPipe::DSL;
 
+# ABSTRACT: shortcuts to building an B<IPC::PrettyPipe> object
+
 use strict;
 use warnings;
 
+our $VERSION = '0.08';
+
 use Carp;
 our @CARP_NOT;
 
@@ -35,9 +18,6 @@ use IPC::PrettyPipe::Cmd;
 use IPC::PrettyPipe::Arg;
 use IPC::PrettyPipe::Stream;
 
-our $VERSION = '1.21';
-
-
 use parent 'Exporter';
 
 our %EXPORT_TAGS = (
@@ -141,12 +121,30 @@ sub ppipe {
 
 1;
 
+#
+# This file is part of IPC-PrettyPipe
+#
+# This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
 
 __END__
 
+=pod
+
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory argpfx argsep pparg ppcmd
+ppipe ppstream
+
 =head1 NAME
 
-B<IPC::PrettyPipe::DSL> - shortcuts to building an B<L<IPC::PrettyPipe>> object
+IPC::PrettyPipe::DSL - shortcuts to building an B<IPC::PrettyPipe> object
+
+=head1 VERSION
+
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -193,20 +191,18 @@ B<IPC::PrettyPipe::DSL> - shortcuts to building an B<L<IPC::PrettyPipe>> object
 B<IPC::PrettyPipe::DSL> provides some shortcut functions to make
 building pipelines easier.
 
-
 =head1 FUNCTIONS
 
-
-Pipelines are created by chainging together commands with arguments.
+Pipelines are created by changing together commands with arguments.
 Arguments which are options may have I<prefixes>, and options which
 have values may have their names separated from their values by a
 I<separator> string.
 
-The B<ppipe>, B<ppcmd>, and B<pparg> functions are used to create
+The B<L</ppipe>>, B<L</ppcmd>>, and B<L</pparg>> functions are used to create
 pipelines, commands, and arguments.
 
-The B<argpfx>, and B<argsep> functions are used to change the argument
-prefix and separator strings.  Calls to these are embeded in lists of
+The B<L</argpfx>>, and B<L</argsep>> functions are used to change the argument
+prefix and separator strings.  Calls to these are embedded in lists of
 arguments and commands, and change the argument prefixes and separator
 strings for the succeeding entries.  These are called I<argument
 attribute modifiers> and are documented in L</Argument Attribute
@@ -214,7 +210,7 @@ Modifiers>.
 
 To specify stream redirection for either pipelines or commands, insert
 either a B<L<IPC::PrettyPipe::Stream>> object or a string stream
-specification (see L<IPC::PrettyPipe::Stream::Util/Stream
+specification (see L<IPC::PrettyPipe::Stream::Utils/Stream
 Specification>).  If the redirection requires another parameter, it
 should immediately follow the object or string specification.
 
@@ -260,10 +256,7 @@ should immediately follow the object or string specification.
       # cmd4
       'cmd4';
 
-
-
-
-B<ppipe> creates an B<IPC::PrettyPipe> object.  It is passed (in order)
+B<ppipe> creates an B<L<IPC::PrettyPipe>> object.  It is passed (in order)
 
 =over
 
@@ -317,7 +310,7 @@ and arguments which follow.
 
 =item *
 
-A stream specification (L<IPC::PrettyPipe::Stream::Util/Stream
+A stream specification (L<IPC::PrettyPipe::Stream::Utils/Stream
 Specification>), or an B<L<IPC::PrettyPipe::Stream>> object. If the
 specification requires an additional parameter, the next value in
 C<@args> is used.
@@ -377,7 +370,7 @@ command in a random order;
 =item *
 
 B<L<IPC::PrettyPipe::Stream>> objects or stream specifications
-(L<IPC::PrettyPipe::Stream::Util/Stream Specification>).  If the
+(L<IPC::PrettyPipe::Stream::Utils/Stream Specification>).  If the
 specification requires an additional parameter, the next value in
 C<@cmd_args> will be used for that parameter.
 
@@ -414,13 +407,12 @@ An optional value.
 
 =back
 
-
 =item B<ppstream>
 
   $stream = ppstream $spec;
   $stream = ppstream $spec, $file;
 
-B<ppstream> creates an B<IPC::PrettyPipe::Stream> object.
+B<ppstream> creates an B<L<IPC::PrettyPipe::Stream>> object.
 It is passed (in order):
 
 =over
@@ -462,7 +454,6 @@ commands, e.g.
              [ 'cmd1', argpfx('-'), 'arg1' ],
              [ 'cmd2', 'arg0' ];
 
-
 and affect the default value of the attribute for the remainder of the
 context in which they are specified.
 
@@ -478,16 +469,44 @@ For example, after the above code is run, the following holds:
   $p->cmds->[2]->argpfx eq '--'
   $p->cmds->[2]->args->[0]->argpfx eq '--'
 
-=head1 COPYRIGHT & LICENSE
+=head1 BUGS
 
-Copyright 2013 Smithsonian Astrophysical Observatory
+Please report any bugs or feature requests on the bugtracker website
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=IPC-PrettyPipe> or by
+email to
+L<bug-IPC-PrettyPipe@rt.cpan.org|mailto:bug-IPC-PrettyPipe@rt.cpan.org>.
 
-This software is released under the GNU General Public License.  You
-may find a copy at
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-   http://www.fsf.org/copyleft/gpl.html
+=head1 SOURCE
 
+The development version is on github at L<https://github.com/djerius/ipc-prettypipe>
+and may be cloned from L<git://github.com/djerius/ipc-prettypipe.git>
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<IPC::PrettyPipe|IPC::PrettyPipe>
+
+=back
 
 =head1 AUTHOR
 
-Diab Jerius E<lt>djerius@cfa.harvard.eduE<gt>
+Diab Jerius <djerius@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
+=cut
