@@ -1,35 +1,27 @@
-# --8<--8<--8<--8<--
-#
-# Copyright (C) 2014 Smithsonian Astrophysical Observatory
-#
-# This file is part of IPC::PrettyPipe
-#
-# IPC::PrettyPipe is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or (at
-# your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# -->8-->8-->8-->8--
-
 package IPC::PrettyPipe::Execute::IPC::Run;
 
+# ABSTRACT: execution backend using IPC::Run
+
 use 5.10.0;
 
-use Moo;
 use Types::Standard qw[ InstanceOf ];
 
+
 use Try::Tiny;
 use IPC::Run ();
+use Carp ();
 
-use Carp;
+use Moo;
+our $VERSION = '0.08';
+
+use namespace::clean;
+
+
+#pod =attr pipe
+#pod
+#pod The C<IPC::PrettyPipe> object which will provide the commands
+#pod
+#pod =cut
 
 has pipe => (
     is       => 'ro',
@@ -107,7 +99,7 @@ after 'run', 'finish' => sub {
 
     catch {
 
-        croak $_;
+        Carp::croak $_;
 
     }
 
@@ -124,10 +116,29 @@ with 'IPC::PrettyPipe::Executor';
 
 1;
 
+#
+# This file is part of IPC-PrettyPipe
+#
+# This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
+__END__
+
+=pod
+
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory
 
 =head1 NAME
 
-B<IPC::PrettyPipe::Execute::IPC::Run> - execution backend using B<IPC::Run>
+IPC::PrettyPipe::Execute::IPC::Run - execution backend using IPC::Run
+
+=head1 VERSION
+
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -140,7 +151,6 @@ B<IPC::PrettyPipe::Execute::IPC::Run> - execution backend using B<IPC::Run>
   my $executor = IPC::PrettyPipe::Execute::IPC::Run->new;
   $pipe->executor( $executor );
 
-
 =head1 DESCRIPTION
 
 B<IPC::PrettyPipe::Execute::IPC::Run> implements the
@@ -155,6 +165,12 @@ When using the proxied methods, the caller must ensure that the
 B<L</finish>> method is invoked to ensure that the parent processes'
 file descriptors are properly restored.
 
+=head1 ATTRIBUTES
+
+=head2 pipe
+
+The C<IPC::PrettyPipe> object which will provide the commands
+
 =head1 Methods
 
 =over
@@ -177,19 +193,44 @@ Invoke the B<L<IPC::Run>> B<L<finish|IPC::Run/finish>> method.
 
 =back
 
+=head1 BUGS
 
-=head1 COPYRIGHT & LICENSE
+Please report any bugs or feature requests on the bugtracker website
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=IPC-PrettyPipe> or by
+email to
+L<bug-IPC-PrettyPipe@rt.cpan.org|mailto:bug-IPC-PrettyPipe@rt.cpan.org>.
 
-Copyright 2014 Smithsonian Astrophysical Observatory
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-This software is released under the GNU General Public License.  You
-may find a copy at
+=head1 SOURCE
 
-   http://www.fsf.org/copyleft/gpl.html
+The development version is on github at L<https://github.com/djerius/ipc-prettypipe>
+and may be cloned from L<git://github.com/djerius/ipc-prettypipe.git>
 
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<IPC::PrettyPipe|IPC::PrettyPipe>
+
+=back
 
 =head1 AUTHOR
 
-Diab Jerius E<lt>djerius@cfa.harvard.eduE<gt>
+Diab Jerius <djerius@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
 
 =cut
