@@ -1,29 +1,7 @@
-#!perl
-
-# --8<--8<--8<--8<--
-#
-# Copyright (C) 2014 Smithsonian Astrophysical Observatory
-#
-# This file is part of IPC::PrettyPipe
-#
-# IPC::PrettyPipe is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or (at
-# your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# -->8-->8-->8-->8--
-
-
 package IPC::PrettyPipe::Render::Template::Tiny;
 
+# ABSTRACT: rendering backend using B<Template::Tiny>
+
 use Carp;
 use Template::Tiny;
 use Safe::Isa;
@@ -32,6 +10,9 @@ use Moo;
 use Types::Standard -all;
 use Type::Params qw[ validate ];
 
+
+our $VERSION = '0.08';
+
 BEGIN {
     if ( $^O =~ /Win32/i ) {
         require Win32::Console::ANSI;
@@ -39,6 +20,8 @@ BEGIN {
 }
 use Term::ANSIColor ();
 
+use namespace::clean;
+
 
 has pipe => (
     is       => 'rw',
@@ -84,22 +67,22 @@ has template => (
 [% END -%]
 [%- FOREACH cmd IN pipe.cmds.elements %]
 [%- IF cmd.first %]  [% ELSE %]\t\\
-| [% END %][% color.cmd.cmd %][% cmd.cmd %][% color.reset %]
+| [% END %][% color.cmd.cmd %][% cmd.quoted_cmd %][% color.reset %]
 [%- FOREACH arg IN cmd.args.elements %]\t\\
     [% color.cmd.arg.pfx %][% arg.pfx %]
-[%- color.cmd.arg.name %][% arg.name %]
+[%- color.cmd.arg.name %][% arg.quoted_name %]
 [%- IF arg.has_value %][%- IF arg.sep %][% color.cmd.arg.sep %][% arg.sep %][% ELSE %] [% END %]
-[%- color.cmd.arg.value %][% IF arg.has_blank_value%]''[% ELSE %][% arg.value %][% END %][% END %][% color.reset %]
+[%- color.cmd.arg.value %][% arg.quoted_value %][% END %][% color.reset %]
 [%- END %]
 [%- FOREACH stream IN cmd.streams.elements %]\t\\
 [% color.cmd.stream.spec %][% stream.spec %]
-[%- IF stream.file %] [% END %][% color.cmd.stream.file %][% stream.file %][% color.reset %]
+[%- IF stream.has_file %] [% END %][% color.cmd.stream.file %][% stream.quoted_file %][% color.reset %]
 [%- END %]
 [%- END %]
 [%- IF pipe.streams.empty %][% ELSE %]\t\\
 )[% FOREACH stream IN pipe.streams.elements %]\t\\
 [% color.pipe.stream.spec %][% stream.spec -%]
-[%- IF stream.file %] [% END %][% color.pipe.stream.file %][% stream.file %][% color.reset %]
+[%- IF stream.has_file %] [% END %][% color.pipe.stream.file %][% stream.quoted_file %][% color.reset %]
 [%- END %]
 [%- END %]
 EOT
@@ -135,12 +118,12 @@ sub render {
 
     my $self = shift;
 
-    my ( $args ) = 
+    my ( $args ) =
       validate( \@_,
-		slurpy Dict[
-			    colorize => Optional[ Bool ],
-			   ]
-	      );
+                slurpy Dict[
+                            colorize => Optional[ Bool ],
+                           ]
+              );
 
 
 
@@ -148,8 +131,6 @@ sub render {
 
     my $output;
 
-    my $colors = $self->colors;
-
     my %color;
     _colorize( $self->colors, \%color );
 
@@ -160,7 +141,7 @@ sub render {
     Template::Tiny->new->process(
         \$self->template,
         {
-	 ## no critic (ProhibitAccessOfPrivateData)
+         ## no critic (ProhibitAccessOfPrivateData)
             pipe => $self->pipe,
             $args->{colorize} ? ( color => \%color ) : (),
         },
@@ -174,11 +155,29 @@ with 'IPC::PrettyPipe::Renderer';
 
 1;
 
+#
+# This file is part of IPC-PrettyPipe
+#
+# This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
 __END__
 
+=pod
+
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory cmds renderer
+
 =head1 NAME
 
-B<IPC::PrettyPipe::Render::Template::Tiny> - rendering backend using B<L<Template::Tiny>>
+IPC::PrettyPipe::Render::Template::Tiny - rendering backend using B<Template::Tiny>
+
+=head1 VERSION
+
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -194,7 +193,7 @@ B<IPC::PrettyPipe::Render::Template::Tiny> - rendering backend using B<L<Templat
 =head1 DESCRIPTION
 
 B<IPC::PrettyPipe::Render::Template::Tiny> implements the
-B<L<IPC::PrettyPipe::Renderer>> role, providing a renderding backend for
+B<L<IPC::PrettyPipe::Renderer>> role, providing a rendering backend for
 B<L<IPC::PrettyPipe>> using the B<L<Template::Tiny>> module.
 
 =head1 METHODS
@@ -225,7 +224,6 @@ Template>.
 
 =back
 
-
 =item render
 
   $renderer->render( %options );
@@ -283,7 +281,6 @@ support loop constructs, so the B<L<IPC::PrettyPipe>> B<L<streams|IPC::PrettyPip
 B<L<cmds|IPC::PrettyPipe/cmds>> methods return B<L<IPC::PrettyPipe::Queue>> objects, which
 provide methods for determining if the lists are empty.
 
-
   [% IF pipe.streams.empty %][% ELSE %](\t\\
   [% END -%]
 
@@ -310,7 +307,6 @@ and colorize a command:
 
   [% color.cmd.cmd %][% cmd.cmd %][% color.reset %]
 
-
 =back
 
 The default template (encoded into the source file for
@@ -342,20 +338,44 @@ stored as a hashref with the following default contents:
       },
   },
 
+=head1 BUGS
 
-=head1 COPYRIGHT & LICENSE
+Please report any bugs or feature requests on the bugtracker website
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=IPC-PrettyPipe> or by
+email to
+L<bug-IPC-PrettyPipe@rt.cpan.org|mailto:bug-IPC-PrettyPipe@rt.cpan.org>.
 
-Copyright 2013 Smithsonian Astrophysical Observatory
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-This software is released under the GNU General Public License.  You
-may find a copy at
+=head1 SOURCE
 
-   http://www.fsf.org/copyleft/gpl.html
+The development version is on github at L<https://github.com/djerius/ipc-prettypipe>
+and may be cloned from L<git://github.com/djerius/ipc-prettypipe.git>
 
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<IPC::PrettyPipe|IPC::PrettyPipe>
+
+=back
 
 =head1 AUTHOR
 
-Diab Jerius E<lt>djerius@cfa.harvard.eduE<gt>
+Diab Jerius <djerius@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
 
 =cut
-
