@@ -1,29 +1,12 @@
-# --8<--8<--8<--8<--
-#
-# Copyright (C) 2014 Smithsonian Astrophysical Observatory
-#
-# This file is part of IPC::PrettyPipe
-#
-# IPC::PrettyPipe is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or (at
-# your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# -->8-->8-->8-->8--
-
 package IPC::PrettyPipe::Stream::Utils;
 
+# ABSTRACT: support utilities for streams
+
 use strict;
 use warnings;
 
+our $VERSION = '0.08';
+
 use parent 'Exporter';
 
 our @EXPORT_OK = qw[ parse_spec ];
@@ -39,45 +22,47 @@ sub parse_spec {
     # for consistency, N is always the descriptor which needs to
     # be opened or dup'ed to. M is never touched.
 
-    $op =~ /^(?:
-    # <, N<
-    # >, N>
-    # >>, N>>
+    return {}
+      unless $op =~ /^(?:
+                 # <, N<
+                 # >, N>
+                 # >>, N>>
 
-      (?'redirect'
-          (?'N' \d+ (?!<<) )?  # don't match N<<
-          (?'Op'
-              (?: [<>]{1,2} )
-          )
-       )
+                   (?'redirect'
+                       (?'N' \d+ (?!<<) )?  # don't match N<<
+                       (?'Op'
+                           (?: [<>]{1,2} )
+                       )
+                    )
 
-    # >&, &>
-    | (?'redirect_stdout_stderr'
-          (?'Op' >& | &> )
-      )
+                 # >&, &>
+                 | (?'redirect_stdout_stderr'
+                       (?'Op' >& | &> )
+                   )
 
-    # N<&-
-    | (?'close'
-          (?'N'  \d+ )
-          (?'Op' <&  )
-          (?'M'  -   )
-       )
+                 # N<&-
+                 | (?'close'
+                       (?'N'  \d+ )
+                       (?'Op' <&  )
+                       (?'M'  -   )
+                    )
 
-    # M<&N
-    | (?'dup'
-          (?'M'  \d+ )
-          (?'Op' <&  )
-          (?'N'  \d+ )
-      )
+                 # M<&N
+                 | (?'dup'
+                       (?'M'  \d+ )
+                       (?'Op' <&  )
+                       (?'N'  \d+ )
+                   )
 
-    # N>&M
-    | (?'dup'
-          (?'N'  \d+ )
-          (?'Op' >&  )
-          (?'M'  \d+ )
-      )
+                 # N>&M
+                 | (?'dup'
+                       (?'N'  \d+ )
+                       (?'Op' >&  )
+                       (?'M'  \d+ )
+                   )
 
-      )$/x;
+               )$/x
+      ;
 
     # force a copy of the hash; it's magical and a simple return
     # of the elements doesn't work.
@@ -98,11 +83,29 @@ sub parse_spec {
 
 1;
 
+#
+# This file is part of IPC-PrettyPipe
+#
+# This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
 __END__
 
+=pod
+
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory
+
 =head1 NAME
 
-B<IPC::PrettyPipe::Stream::Utils> - support utilities for streams
+IPC::PrettyPipe::Stream::Utils - support utilities for streams
+
+=head1 VERSION
+
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -174,17 +177,44 @@ C<param> will be set.
 
 =back
 
+=head1 BUGS
 
-=head1 COPYRIGHT & LICENSE
+Please report any bugs or feature requests on the bugtracker website
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=IPC-PrettyPipe> or by
+email to
+L<bug-IPC-PrettyPipe@rt.cpan.org|mailto:bug-IPC-PrettyPipe@rt.cpan.org>.
 
-Copyright 2014 Smithsonian Astrophysical Observatory
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-This software is released under the GNU General Public License.  You
-may find a copy at
+=head1 SOURCE
 
-   http://www.fsf.org/copyleft/gpl.html
+The development version is on github at L<https://github.com/djerius/ipc-prettypipe>
+and may be cloned from L<git://github.com/djerius/ipc-prettypipe.git>
 
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<IPC::PrettyPipe|IPC::PrettyPipe>
+
+=back
 
 =head1 AUTHOR
 
-Diab Jerius E<lt>djerius@cfa.harvard.eduE<gt>
+Diab Jerius <djerius@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
+=cut
